0.9.9 API documentation: GLM_GTX_fast_exponential

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_GTX_fast_exponential
Experimental extensions

Include <glm/gtx/fast_exponential.hpp> to use the features of this extension. More...

## Functions
template<typename T >
GLM_FUNC_DECL T | fastExp (T x)
| Faster than the common exp function but less accurate. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | fastExp (vec< L, T, Q > const &x)
| Faster than the common exp function but less accurate. More...
template<typename T >
GLM_FUNC_DECL T | fastExp2 (T x)
| Faster than the common exp2 function but less accurate. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | fastExp2 (vec< L, T, Q > const &x)
| Faster than the common exp2 function but less accurate. More...
template<typename T >
GLM_FUNC_DECL T | fastLog (T x)
| Faster than the common log function but less accurate. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | fastLog (vec< L, T, Q > const &x)
| Faster than the common exp2 function but less accurate. More...
template<typename T >
GLM_FUNC_DECL T | fastLog2 (T x)
| Faster than the common log2 function but less accurate. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | fastLog2 (vec< L, T, Q > const &x)
| Faster than the common log2 function but less accurate. More...
template<typename genType >
GLM_FUNC_DECL genType | fastPow (genType x, genType y)
| Faster than the common pow function but less accurate. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | fastPow (vec< L, T, Q > const &x, vec< L, T, Q > const &y)
| Faster than the common pow function but less accurate. More...
template<typename genTypeT , typename genTypeU >
GLM_FUNC_DECL genTypeT | fastPow (genTypeT x, genTypeU y)
| Faster than the common pow function but less accurate. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | fastPow (vec< L, T, Q > const &x)
| Faster than the common pow function but less accurate. More...

## Detailed Description

Include <glm/gtx/fast_exponential.hpp> to use the features of this extension.

Fast but less accurate implementations of exponential based functions.

## Function Documentation

GLM_FUNC_DECL T glm::fastExp | ( | T | x | ) |

Faster than the common exp function but less accurate.

See also
  GLM_GTX_fast_exponential

GLM_FUNC_DECL vec<L, T, Q> glm::fastExp | ( | vec< L, T, Q > const & | x | ) |

Faster than the common exp function but less accurate.

See also
  GLM_GTX_fast_exponential

GLM_FUNC_DECL T glm::fastExp2 | ( | T | x | ) |

Faster than the common exp2 function but less accurate.

See also
  GLM_GTX_fast_exponential

GLM_FUNC_DECL vec<L, T, Q> glm::fastExp2 | ( | vec< L, T, Q > const & | x | ) |

Faster than the common exp2 function but less accurate.

See also
  GLM_GTX_fast_exponential

GLM_FUNC_DECL T glm::fastLog | ( | T | x | ) |

Faster than the common log function but less accurate.

See also
  GLM_GTX_fast_exponential

GLM_FUNC_DECL vec<L, T, Q> glm::fastLog | ( | vec< L, T, Q > const & | x | ) |

Faster than the common exp2 function but less accurate.

See also
  GLM_GTX_fast_exponential

GLM_FUNC_DECL T glm::fastLog2 | ( | T | x | ) |

Faster than the common log2 function but less accurate.

See also
  GLM_GTX_fast_exponential

GLM_FUNC_DECL vec<L, T, Q> glm::fastLog2 | ( | vec< L, T, Q > const & | x | ) |

Faster than the common log2 function but less accurate.

See also
  GLM_GTX_fast_exponential

GLM_FUNC_DECL genType glm::fastPow | ( | genType | x,
|  | genType | y
| ) |  |

Faster than the common pow function but less accurate.

See also
  GLM_GTX_fast_exponential

GLM_FUNC_DECL vec<L, T, Q> glm::fastPow | ( | vec< L, T, Q > const & | x,
|  | vec< L, T, Q > const & | y
| ) |  |

Faster than the common pow function but less accurate.

See also
  GLM_GTX_fast_exponential

GLM_FUNC_DECL genTypeT glm::fastPow | ( | genTypeT | x,
|  | genTypeU | y
| ) |  |

Faster than the common pow function but less accurate.

See also
  GLM_GTX_fast_exponential

GLM_FUNC_DECL vec<L, T, Q> glm::fastPow | ( | vec< L, T, Q > const & | x | ) |

Faster than the common pow function but less accurate.

See also
  GLM_GTX_fast_exponential